Example documentation
=====================

.. toctree::

    test_module
    test_module_summary_only
    test_class
    test_class_order
    test_class_summary_only
    test_inherited
    test_module_title
    test_module_no_nesting
    test_autoclasssumm
    test_autoclasssumm_some_sections
    test_autoclasssumm_no_titles
    test_automodulesumm
    test_automodulesumm_some_sections
    test_empty
    test_class_submodule
    test_module_submodule